<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>本程式必須以 root 身份來執行。</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="443"/>
        <source>MX Boot Repair</source>
        <translation>MX 開機修復</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>你想要進行哪一項作業？</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>備份 MBR 或 PBR（僅限舊式開機）</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>修復 GRUB 設定檔</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>自備份回復 MBR 或 PBR（僅限舊式開機）</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="376"/>
        <source>Select Boot Method</source>
        <translation>選擇開機方式</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>主要開機記錄區</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="417"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>根目錄（磁碟區開機記錄區）</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>root</source>
        <translation>根目錄</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="377"/>
        <source>Install on:</source>
        <translation>安裝在：</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>選擇 /boot 位置：</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>EFI 系統磁碟區</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>關於本程式</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>關於……</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="459"/>
        <source>Display help </source>
        <translation>顯示說明</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="462"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="469"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="510"/>
        <source>Cancel any changes then quit</source>
        <translation>取消所有更動，然後退出</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="513"/>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="520"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="539"/>
        <source>Apply any changes</source>
        <translation>採用所有更動</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <location filename="../mxbootrepair.cpp" line="76"/>
        <source>Apply</source>
        <translation>使用</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="94"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="109"/>
        <location filename="../mxbootrepair.cpp" line="132"/>
        <location filename="../mxbootrepair.cpp" line="162"/>
        <location filename="../mxbootrepair.cpp" line="264"/>
        <location filename="../mxbootrepair.cpp" line="298"/>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="110"/>
        <source>Could not mount </source>
        <translation>無法將 </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="110"/>
        <source> on /boot/efi</source>
        <translation> 掛載到 /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="133"/>
        <location filename="../mxbootrepair.cpp" line="163"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>無法設置 chroot 環境。
請再次確認選定的位置是否正確。</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="150"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="184"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="239"/>
        <source>Warning</source>
        <translation>注意</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source>You are going to write the content of </source>
        <translation>即將把 </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source> to </source>
        <translation> 的內容寫入 </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source>

Are you sure?</source>
        <translation>

確定要進行嗎？</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">是</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">否</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="245"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="265"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>在系統上所有的磁碟當中都找不到 EFI 系統磁碟區（ESP）。請先創造 ESP，然後再試一次。</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="292"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="293"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>程序順利執行完畢。&lt;p&gt;&lt;b&gt;是否要退出 MX 開機修復工具？&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="299"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>程序結束。過程中發生錯誤。</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Back</source>
        <translation>上一步</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="385"/>
        <source>Select GRUB location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="396"/>
        <source>Select Item to Back Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="403"/>
        <source>Select Item to Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="414"/>
        <source>Select backup file name</source>
        <translation>選擇備份檔檔名</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>No file was selected.</source>
        <translation>未選擇任何檔案。</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="421"/>
        <source>Select MBR or PBR backup file</source>
        <translation>選擇 MBR 或 PBR 備份檔</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="442"/>
        <source>About MX Boot Repair</source>
        <translation>關於 MX 開機修復</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="443"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>MX Linux 的簡易開機修復程式</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="446"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="470"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
</context>
</TS>
